@@ -56,7 +56,7 @@ class ARQ:
         Download a prunhub video.
             Returns result object with a link which you can access with dot notation
 
-    luna(query="hello luna"):
+    luna(query="hello luna", id=user_id):
         Communicate with an AI chatbot.
             Returns result object which you can access with dot notation.
 
@@ -152,9 +152,7 @@ class ARQ:
                         result[result_number].title | .id | .source | .duration | .thumbnail | .artist | .url
 
         """
-        return await self._fetch(
-            "deezer", {"query": query, "count": count}
-        )
+        return await self._fetch("deezer", {"query": query, "count": count})
 
     async def torrent(self, query: str):
         """
@@ -270,16 +268,17 @@ class ARQ:
         """
         return await self._fetch("phdl", {"url": url})
 
-    async def luna(self, query: str):
+    async def luna(self, query: str, id: int = 0):
         """
         Returns An Object.
 
                 Parameters:
                         query (str): Query to compute
+                        id (int): Unique user_id.
                 Returns:
                         result object (str): Result
         """
-        return await self._fetch("luna", {"query": query})
+        return await self._fetch("luna", {"query": query, "id": id})
 
     async def lyrics(self, query: str):
         """
@@ -382,6 +381,12 @@ class ARQ:
 
                         results
         """
+        def getName(from_user):
+            first_name = from_user.first_name
+            last_name = from_user.last_name if from_user.last_name else ""
+            name = first_name + last_name
+            return name
+
         payload = {
             "type": "quote",
             "format": "png",
@@ -398,7 +403,9 @@ class ARQ:
                     ]
                     if message.entities
                     else [],
-                    "chatId": message.from_user.id,
+                    "chatId": message.forward_from.id
+                    if message.forward_from
+                    else message.from_user.id,
                     "avatar": True,
                     "from": {
                         "id": message.from_user.id,
@@ -406,22 +413,39 @@ class ARQ:
                         if message.from_user.username
                         else "",
                         "photo": {
-                            "small_file_id": message.photo.small_file_id,
-                            "small_photo_unique_id": message.photo.small_photo_unique_id,
-                            "big_file_id": message.photo.big_file_id,
-                            "big_photo_unique_id": message.photo.big_photo_unique_id,
+                            "small_file_id": message.from_user.photo.small_file_id,
+                            "small_photo_unique_id": message.from_user.photo.small_photo_unique_id,
+                            "big_file_id": message.from_user.photo.big_file_id,
+                            "big_photo_unique_id": message.from_user.photo.big_photo_unique_id,
                         }
-                        if message.photo
+                        if message.from_user.photo
                         else "",
                         "type": message.chat.type,
-                        "name": (
-                            message.from_user.first_name + message.from_user.last_name
-                        )
-                        if message.from_user.last_name
-                        else message.from_user.first_name,
+                        "name": getName(message.from_user),
+                    }
+                    if not message.forward_from
+                    else {
+                        "id": message.forward_from.id,
+                        "username": message.forward_from.username
+                        if message.forward_from.username
+                        else "",
+                        "photo": {
+                            "small_file_id": message.forward_from.photo.small_file_id,
+                            "small_photo_unique_id": message.forward_from.photo.small_photo_unique_id,
+                            "big_file_id": message.forward_from.photo.big_file_id,
+                            "big_photo_unique_id": message.forward_from.photo.big_photo_unique_id,
+                        }
+                        if message.forward_from.photo
+                        else "",
+                        "type": message.chat.type,
+                        "name": getName(message.forward_from),
                     },
                     "text": message.text if message.text else "",
-                    "replyMessage": {},
+                    "replyMessage": ({
+                        "name": getName(message.reply_to_message.from_user),
+                        "text": message.reply_to_message.text,
+                        "chatId": message.reply_to_message.from_user.id
+                        } if message.reply_to_message else {}) if len(messages) == 1 else {},
                 }
                 for message in messages
             ],
